==> jc-1.4.0.tar.gz: polyglot/frontend/CupParser.h <==
// public class polyglot.frontend.CupParser

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 30d3b18b1554b931 polyglot_frontend_CupParser

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_frontend_CupParser_H_
#define _JC_polyglot_frontend_CupParser_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java__5fcup_runtime_lr__5fparser$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_frontend_Source$object;
struct _jc_polyglot_util_ErrorQueue$object;

// Typedefs
typedef struct _jc_polyglot_frontend_CupParser$sub_refs	_jc_polyglot_frontend_CupParser$sub_refs;
typedef struct _jc_polyglot_frontend_CupParser$sub_nonrefs	_jc_polyglot_frontend_CupParser$sub_nonrefs;
typedef struct _jc_polyglot_frontend_CupParser$refs	_jc_polyglot_frontend_CupParser$refs;
typedef struct _jc_polyglot_frontend_CupParser$nonrefs	_jc_polyglot_frontend_CupParser$nonrefs;
typedef struct _jc_polyglot_frontend_CupParser$object	_jc_polyglot_frontend_CupParser$object;

typedef const struct _jc_polyglot_frontend_CupParser$vmethods	_jc_polyglot_frontend_CupParser$vmethods;
typedef const struct _jc_polyglot_frontend_CupParser$vtable	_jc_polyglot_frontend_CupParser$vtable;
typedef const struct _jc_polyglot_frontend_CupParser$vtype	_jc_polyglot_frontend_CupParser$vtype;

// Constructors
extern void _jc_polyglot_frontend_CupParser$method$_init$14811b927e304a88(_jc_env *, struct _jc_polyglot_frontend_CupParser$object *, struct _jc_java__5fcup_runtime_lr__5fparser$object *, struct _jc_polyglot_frontend_Source$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_frontend_CupParser$method$parse$f63615b526cd2371(_jc_env *, struct _jc_polyglot_frontend_CupParser$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_CupParser$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_frontend_CupParser$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_CupParser$method_info$parse$f63615b526cd2371;
extern _jc_method _jc_polyglot_frontend_CupParser$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_frontend_CupParser$vmethods {
	struct _jc_object	*(*parse$f63615b526cd2371)(_jc_env *, struct _jc_polyglot_frontend_CupParser$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_frontend_CupParser$object *);
};

// Vtable
struct _jc_polyglot_frontend_CupParser$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_CupParser$vmethods	polyglot_frontend_CupParser;
};

// Vtype
struct _jc_polyglot_frontend_CupParser$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_CupParser$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_CupParser$sub_refs {
	struct _jc_java__5fcup_runtime_lr__5fparser$object	*grm;
	struct _jc_polyglot_frontend_Source$object	*source;
	struct _jc_object	*eq;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_CupParser$refs {
    _jc_polyglot_frontend_CupParser$sub_refs	polyglot_frontend_CupParser;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_CupParser$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_CupParser$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_CupParser$sub_nonrefs	polyglot_frontend_CupParser;
};

// Object instance structure
struct _jc_polyglot_frontend_CupParser$object {
	_jc_polyglot_frontend_CupParser$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_CupParser$vtype	*vtype;
	_jc_polyglot_frontend_CupParser$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_CupParser$vtype _jc_polyglot_frontend_CupParser$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_CupParser, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_CupParser$class_object;

#endif	/* _JC_polyglot_frontend_CupParser_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/CupParser.h <==
// public class polyglot.frontend.CupParser

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 30d3b18b1554b931 polyglot_frontend_CupParser

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_frontend_CupParser_H_
#define _JC_polyglot_frontend_CupParser_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java__5fcup_runtime_lr__5fparser$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_frontend_Source$object;
struct _jc_polyglot_util_ErrorQueue$object;

// Typedefs
typedef struct _jc_polyglot_frontend_CupParser$sub_refs	_jc_polyglot_frontend_CupParser$sub_refs;
typedef struct _jc_polyglot_frontend_CupParser$sub_nonrefs	_jc_polyglot_frontend_CupParser$sub_nonrefs;
typedef struct _jc_polyglot_frontend_CupParser$refs	_jc_polyglot_frontend_CupParser$refs;
typedef struct _jc_polyglot_frontend_CupParser$nonrefs	_jc_polyglot_frontend_CupParser$nonrefs;
typedef struct _jc_polyglot_frontend_CupParser$object	_jc_polyglot_frontend_CupParser$object;

typedef const struct _jc_polyglot_frontend_CupParser$vmethods	_jc_polyglot_frontend_CupParser$vmethods;
typedef const struct _jc_polyglot_frontend_CupParser$vtable	_jc_polyglot_frontend_CupParser$vtable;
typedef const struct _jc_polyglot_frontend_CupParser$vtype	_jc_polyglot_frontend_CupParser$vtype;

// Constructors
extern void _jc_polyglot_frontend_CupParser$method$_init$14811b927e304a88(_jc_env *, struct _jc_polyglot_frontend_CupParser$object *, struct _jc_java__5fcup_runtime_lr__5fparser$object *, struct _jc_polyglot_frontend_Source$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_frontend_CupParser$method$parse$f63615b526cd2371(_jc_env *, struct _jc_polyglot_frontend_CupParser$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_CupParser$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_frontend_CupParser$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_CupParser$method_info$parse$f63615b526cd2371;
extern _jc_method _jc_polyglot_frontend_CupParser$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_frontend_CupParser$vmethods {
	struct _jc_object	*(*parse$f63615b526cd2371)(_jc_env *, struct _jc_polyglot_frontend_CupParser$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_frontend_CupParser$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_frontend_CupParser$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_CupParser$vmethods	polyglot_frontend_CupParser;
};

// Vtype
struct _jc_polyglot_frontend_CupParser$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_CupParser$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_CupParser$sub_refs {
	struct _jc_java__5fcup_runtime_lr__5fparser$object	*grm;
	struct _jc_polyglot_frontend_Source$object	*source;
	struct _jc_object	*eq;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_CupParser$refs {
    _jc_polyglot_frontend_CupParser$sub_refs	polyglot_frontend_CupParser;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_CupParser$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_CupParser$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_CupParser$sub_nonrefs	polyglot_frontend_CupParser;
};

// Object instance structure
struct _jc_polyglot_frontend_CupParser$object {
	_jc_polyglot_frontend_CupParser$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_CupParser$vtype	*vtype;
	_jc_polyglot_frontend_CupParser$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_CupParser$vtype _jc_polyglot_frontend_CupParser$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_CupParser, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_CupParser$class_object;

#endif	/* _JC_polyglot_frontend_CupParser_H_ */
